import sys
import subprocess
from pathlib import Path

home_virtualenv_folder = ".virtualenvs"
home = str(Path.home())

virtual_env_folder = f"{home}/{home_virtualenv_folder}"


def main():
    args = sys.argv
    if len(args) == 1:
        print("Please specify the name of a virtualenv after the "
              "zappa-env command")
        return
    elif len(args) == 2:
        print("Please specify a zappa command to be ran after loading "
              "zappa from the specified virtualenv")
        return
    virtual_env = args[1]
    other_commands = args[2:]

    subprocess_cmd(
        "source $(which virtualenvwrapper.sh); "
        f"workon {virtual_env}; "
        "echo \"Using virtualenv: $VIRTUAL_ENV to run Zappa command\"; "
        "zappa " + " ".join(other_commands))


def subprocess_cmd(command):
    process = subprocess.Popen(
        command, shell=True, executable="/bin/bash")
    process.communicate()


if __name__ == "__main__":
    main()



from distutils.core import setup

with open('README.md', "r") as readme_file:
    long = readme_file.read()

setup(
    name='zappa-env',         # How you named your package folder (MyLib)
    packages=['zappa_env'],   # Chose the same as "name"
    version='0.251',      # Start with a small number and increase it with every change you make
    # Chose a license from here: https://help.github.com/articles/licensing-a-repository
    license='MIT',
    # Give a short description about your library
    description='Run Zappa commands with Python virtual environments',
    author='Phillip Cutter',                   # Type in your name
    author_email='mrfleap@gmail.com',      # Type in your E-Mail
    # Provide either the link to your github or to your website
    url='https://github.com/mrfleap/zappa-env',
    # I explain this later on
    download_url='https://github.com/mrfleap/zappa-env/archive/0.251.tar.gz',
    # Keywords that define your package best
    keywords=['zappa', 'virtualenv', 'env', 'virtualenvironment'],
    install_requires=[            # I get to this in a second
        'zappa',
    ],
    entry_points={
        'console_scripts': [
            'zappa-env=zappa_env.zappa_env:main',
        ],
    },
    classifiers=[
        # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
        'Development Status :: 4 - Beta',
        # Define that your audience are developers
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',
        'License :: OSI Approved :: MIT License',   # Again, pick a license
        # Specify which pyhton versions that you want to support
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
    ],
    long_description=long,
    long_description_content_type='text/markdown',
)
